using System;
using System.Drawing;
using System.Drawing.Imaging;
using System.Web;
using System.IO;
using System.Configuration;

namespace AspNetGallery.Extensions.Handlers
{
    public class DynImageHandler : IHttpHandler
    {
        public void ProcessRequest(HttpContext context)
        {
            // Process the URL param
            var o1 = context.Request["url"];
            if (o1 == null)
            {
                context.Response.Write("No image found.");
                context.Response.End();
                return;
            }
            var file = context.Server.MapPath(o1);

            // Process the thumbnail param
            var useThumbnail = false;
            var o2 = context.Request["small"];
            if (o2 != null)
            {
                Boolean.TryParse(o2, out useThumbnail);
            }

            // Read copyright string from AppSettings
            var msg = ConfigurationManager.AppSettings["CopyrightNoteForImages"];
            if (File.Exists(file))
            {
                Bitmap bmp;
                if (useThumbnail)
                    bmp = GetThumbnail(file);
                else
                    bmp = AddCopyright(file, msg);

                context.Response.ContentType = "image/jpeg";
                bmp.Save(context.Response.OutputStream, ImageFormat.Jpeg);
                bmp.Dispose();
            }
            else
            {
                context.Response.Write("No image found.");
                context.Response.End();
            }
        }

        public bool IsReusable
        {
            get
            {
                return true;
            }
        }

        #region Helpers
        private static Bitmap GetThumbnail(string file)
        {
            var bmp = new Bitmap(file);
            var newImg = (Bitmap) bmp.GetThumbnailImage(
                bmp.Width / 2, bmp.Height / 2, null, IntPtr.Zero);
            return newImg;
        }

        private static Bitmap AddCopyright(string file, string msg)
        {
            // Load the file and create the graphics
            var bmp = new Bitmap(file);
            var g = Graphics.FromImage(bmp);

            // Define text alignment
            var strFmt = new StringFormat {Alignment = StringAlignment.Center};

            // Create brushes for the bottom writing
            // (green text on black background)
            var btmForeColor = new SolidBrush(Color.PaleGreen);
            var btmBackColor = new SolidBrush(Color.Black);

            // To calculate writing coordinates, obtain the size of the text
            // given font typeface and size
            var btmFont = new Font("Verdana", 7);
            var textSize = g.MeasureString(msg, btmFont);

            // Calculate the output rectangle and fill
            float x = (bmp.Width - textSize.Width - 3);
            float y = (bmp.Height - textSize.Height - 3);
            float w = (x + textSize.Width);
            float h = (y + textSize.Height);
            var textArea = new RectangleF(x, y, w, h);
            g.FillRectangle(btmBackColor, textArea);

            // Draw the text and free resources
            g.DrawString(msg, btmFont, btmForeColor, textArea);
            btmForeColor.Dispose();
            btmBackColor.Dispose();
            btmFont.Dispose();
            g.Dispose();

            return bmp;
        }
        #endregion
    }
}