﻿/**
*   Central repository object for the application. 
*/
var GLOBALS = GLOBALS || {};

/**
*   Quick accessor to a DOM element. 
*   (in case you're not using jQuery)
*
*   @param  {String} id     ID of the DOM element to retrieve
*   @return {DOM}           Selected DOM element, if any    
*/
GLOBALS.$ = window.$ = function (id) {
    return document.getElementById(id);
};

/**
*   Internal helper to programmatically add event handlers.
*   (in case you're not using jQuery)
*
*   @param  {DOM}    elem       DOM element to attach the handler to
*   @param  {String} eventName  Name of the event 
*   @param  {Object} handler    JS function object (not the name)
*/
GLOBALS.addHandler = function (elem, eventName, handler) {
    if (elem.addEventListener) {
        elem.addEventListener(eventName, handler, false);
    } else {
        elem["on" + eventName] = handler;
    }
};

/**
*   Internal helper to register an handler for the DOM ready event. 
*   (in case you're not using jQuery)
*
*   @param  {Object} handler    JS function object (not the name)
*/
GLOBALS.setPageInitializer = function (handler) {
    if (document.addEventListener) {
        GLOBALS.addHandler(document, "DOMContentLoaded", handler);
    } else {
        GLOBALS.addHandler(document, "readystatechange", handler);
    }
};

/**
*   Internal helper to retrieve the target of an event.
*   (in case you're not using jQuery)
*
*   @param  {Object} e    Event object as returned by the browser
*/
GLOBALS.getSrcElement = function (e) {
    e = e || window.event;
    var src = e.target || e.srcElement;
    return src;
};