using System;
using System.Web;
using System.Web.Script.Serialization;

namespace JsonP.Handlers
{
    public class EndpointServer : IHttpHandler
    {
        private const String JsCallbackParameter = "js";

        /// <summary>
        /// This class represents the base class for Web service-like components
        /// supporting JSONP.
        /// </summary>
        /// <param name="context">HTTP context</param>
        public virtual void ProcessRequest(HttpContext context)
        {
            // Ensure the JS callback has been specified. If not, returns the empty string.
            var jsCallback = context.Request[JsCallbackParameter] ?? String.Empty;
            if (String.IsNullOrWhiteSpace(jsCallback))
                return;

            // Figure out the name of the method to call. It gets that from the URL pathinfo.
            var methodName = context.Request.PathInfo.Trim('/');
            var methodInfo = GetType().GetMethod(methodName);
            if (methodInfo == null)
                return;

            // Figure out parameters to pass to the method
            //

            // Execute the method via reflection
            var result = methodInfo.Invoke(this, null);

            // Serialize the result and wrap it in a JSONP response 
            var serializer = new JavaScriptSerializer();
            var output = String.Format("{0}({1})", jsCallback, serializer.Serialize(result));

            // Add a response header to make it also work with IE8+ XDR 
            context.Response.AddHeader("Access-Control-Allow-Origin", "*"); 

            // Prepares the response
            context.Response.ContentType = "application/json";
            context.Response.Write(output);
        }


        public bool IsReusable
        {
            get { return false; }
        }
    }
}