﻿using System;
using System.Web.UI;
using UserProfileDemo.Classes;


namespace UserProfileDemo
{
    public partial class ProfileDemo : Page
    {
        protected void Page_Load(Object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                var info = GrabWeatherInfo();
                DisplayData(info);
            }
        }

        protected void Button1_Click(Object sender, EventArgs e)
        {
            // Persist settings for the current user
            var profile = Classes.UserProfile.GetUserProfile();
            profile.UseEuroMetricSystem = chkEuroMetric.Checked;
            profile.TempSystem = rdlTempSystem.SelectedItem.Value;
            profile.Save();
            Response.Redirect("/profile.aspx");
        }

        private void DisplayData(WeatherInfo info)
        {
            var speedFormat = "{0} mph";

            // THIS IS THE SIMPLEST BUT WEAKLY TYPED SOLUTION
            // Use profile info
            //if ((bool) Profile.GetPropertyValue("UseEuroMetricSystem"))
            //    speedFormat = "{0} kmh";
            //var speedText = String.Format(speedFormat, info.WindSpeed);
            //var tempText = String.Format("{0} {1}", info.Temperature, Profile.GetPropertyValue("TempSystem"));

            
            // Type-safe solution for Web Application projects
            var profile = Classes.UserProfile.GetUserProfile();
            if (profile.UseEuroMetricSystem)
                speedFormat = "{0} kmh";
            var speedText = String.Format(speedFormat, info.WindSpeed);

            var tempText = String.Format("{0} {1}", info.Temperature, profile.TempSystem);
            lblWindSpeed.Text = speedText;
            lblTemperature.Text = tempText;

            // Set the EDIT panel as well
            chkEuroMetric.Checked = profile.UseEuroMetricSystem;
            rdlTempSystem.SelectedIndex = (profile.TempSystem == "F" ? 0 : 1);
        }

        private static WeatherInfo GrabWeatherInfo()
        {
            var rnd = new Random();

            var info = new WeatherInfo
                           {
                               WindSpeed = rnd.Next(0, 100), Temperature = rnd.Next(0, 50)
                           };
            return info;
        }
    }
}