using System;
using System.ComponentModel;
using Mvvm.Model;

namespace Mvvm.ViewModel
{
    public class InventoryViewModel : INotifyPropertyChanged 
    {
        #region Private Members
        private readonly ApplicationItems _applicationItems;
        private ProductInfoForDisplay _productInfoForDisplay;
        private ProductListForDisplay _productListForDisplay;
        #endregion

        #region Constructor
        public InventoryViewModel()
        {
            _applicationItems = new ApplicationItems() { Title = "Inventory Manager >> MVVM", UserText = "1", IsSearchByName = true};
            _productListForDisplay = new ProductListForDisplay();
            _productInfoForDisplay = new ProductInfoForDisplay();
        }
        #endregion

        #region INotifyPropertyChanged
        public event PropertyChangedEventHandler PropertyChanged; 
        #endregion

        #region Notification
        private void NotifyPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
        #endregion

        #region Public Members
        public String Title
        {
            get { return _applicationItems.Title; }
            set { _applicationItems.Title = value; }
        }
        public String UserText
        {
            get { return _applicationItems.UserText; }
            set { _applicationItems.UserText = value; }
        }
        public Boolean IsSearchByName
        {
            get { return _applicationItems.IsSearchByName; }
            set { _applicationItems.IsSearchByName = value; }
        }
        public Boolean IsSearchById
        {
            get { return _applicationItems.IsSearchById; }
            set { _applicationItems.IsSearchById = value; }
        }
        public Boolean IsEmptyInput
        {
            get { return _applicationItems.UserText.Length <=0; }
        }
        public Boolean IsProductPanelVisible
        {
            get { return _applicationItems.IsProductPanelVisible; }
            set 
            { 
                _applicationItems.IsProductPanelVisible = value; 
                NotifyPropertyChanged("IsProductPanelVisible"); 
            }
        }
        public Boolean IsProductListPanelVisible
        {
            get { return _applicationItems.IsProductListPanelVisible; }
            set
            {
                _applicationItems.IsProductListPanelVisible = value;
                NotifyPropertyChanged("IsProductListPanelVisible");
            }
        }

        public ProductInfoForDisplay Product
        {
            get { return _productInfoForDisplay; }
            set
            {
                _productInfoForDisplay = value; 
                NotifyPropertyChanged("Product");
            }
        }
        public ProductListForDisplay Products
        {
            get { return _productListForDisplay; }
            set
            {
                _productListForDisplay = value;
                NotifyPropertyChanged("Products");
            }
        }

        #endregion
    }
}