using System;
using System.Collections.Generic;
using Entities;

namespace LiveQuoteManager.Services
{
    public class RandomQuoteProvider : IQuoteProvider
    {
        /// <summary>
        /// Indicates the name of the financial info provider
        /// </summary>
        public string ProviderName
        {
            get { return "Unknown Provider"; }
        }

        #region IQuoteProvider Members

        public IList<StockInfo> GetQuotes(String symbols)
        {
            return FindQuoteInfo(symbols);
        }

        #endregion


        #region Helpers

        /// <summary>
        /// Gets quotes and related change using the Finance Yahoo web service
        /// </summary>
        /// <param name="symbols">Comma-separated string indicating symbols to retrieve</param>
        /// <returns>Array of StockInfo objects</returns>
        private static StockInfo[] FindQuoteInfo(string symbols)
        {
            // Get an string array to work with
            var elements = symbols.Split(',');

            // Random object
            var rnd = new Random();

            // Create return value object
            var data = new List<StockInfo>();


            // Loop through the symbols
            for (var i = 0; i < elements.Length; i++)
            {
                var stock = new StockInfo
                                {
                                    Company = elements[i],
                                    Date = DateTime.Now.ToShortDateString(),
                                    Time = DateTime.Now.ToShortTimeString()
                                };

                // Random quote
                var d1 = rnd.NextDouble();
                var mult1 = rnd.Next(1, 100);
                d1 = d1 * mult1;
                stock.CurrentQuote = d1.ToString("##0.000");

                // Random change
                var d2 = rnd.NextDouble();
                var mult2 = rnd.Next(1, 10);
                d2 = d2 * mult2;
                string sign = (mult2 % 2 > 0 ? "+" : "-");
                stock.Change = sign + d2.ToString("##0.00") + "%";

                data.Add(stock);
            }

            return data.ToArray();
        }


        #endregion
    }
}